@@ -18,4 +18,8 @@ p = Doptimize(N, k, nrestarts, alpha1, alpha2, alpha3, verbose )
 print('resulting design:')
 print(p)
 
+dd = Defficiencies(N, k, p)
+print('efficiencies:')
+print(dd)
+
 
